@@ -11,10 +11,11 @@ use git2::Repository;
 use spinners::{Spinner, Spinners};
 
 mod purge;
-use crate::lib::CACHE_DIR;
+use crate::lib::{CACHE_DIR, IS_ONLINE};
 pub use purge::purge;
 
-const TO_UPDATE: u64 = 360 * 24;
+/// One Day in seconds
+const TO_UPDATE: u64 = 60 * 60 * 24;
 
 fn clone_repo(url: &str, cache_dir: &str) -> anyhow::Result<Repository> {
     let mut sp = Spinner::new(Spinners::Dots12, "Initializing Cache...".into());
@@ -22,7 +23,7 @@ fn clone_repo(url: &str, cache_dir: &str) -> anyhow::Result<Repository> {
     let r = Repository::clone(url, cache_dir)
         .with_context(|| "Failed to clone gitignore repository")?;
 
-    sp.stop_with_message("Cache Initialized!".into());
+    sp.stop_with_message("Cache Initialized!\n".into());
 
     Ok(r)
 }
@@ -48,7 +49,8 @@ pub fn init_cache() -> anyhow::Result<PathBuf> {
             .unwrap_or(Duration::from_secs(TO_UPDATE))
             .as_secs();
 
-        if since > TO_UPDATE {
+        if since > TO_UPDATE && *IS_ONLINE {
+            fs::remove_dir_all(&cache_dir)?;
             clone_repo(url, cache_dir.to_str().unwrap())?;
         }
 
